You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by sb...@apache.org on 2014/12/12 10:29:28 UTC

[27/67] [abbrv] [partial] incubator-ignite git commit: Rename GridException to IgniteCheckedException, GridRuntimeException to IgniteException.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/continuous/GridCacheContinuousQueryEntry.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/jdbc/GridCacheQueryJdbcMetadataTask.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/jdbc/GridCacheQueryJdbcMetadataTask.java
index b518f23..0f64ab8 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/jdbc/GridCacheQueryJdbcMetadataTask.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/jdbc/GridCacheQueryJdbcMetadataTask.java
@@ -39,7 +39,7 @@ public class GridCacheQueryJdbcMetadataTask extends ComputeTaskAdapter<String, b
 
     /** {@inheritDoc} */
     @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid,
-        @Nullable String cacheName) throws GridException {
+        @Nullable String cacheName) throws IgniteCheckedException {
         Map<JdbcDriverMetadataJob, ClusterNode> map = new HashMap<>();
 
         for (ClusterNode n : subgrid)
@@ -53,7 +53,7 @@ public class GridCacheQueryJdbcMetadataTask extends ComputeTaskAdapter<String, b
     }
 
     /** {@inheritDoc} */
-    @Override public byte[] reduce(List<ComputeJobResult> results) throws GridException {
+    @Override public byte[] reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
         return F.first(results).getData();
     }
 
@@ -92,7 +92,7 @@ public class GridCacheQueryJdbcMetadataTask extends ComputeTaskAdapter<String, b
         }
 
         /** {@inheritDoc} */
-        @Override public Object execute() throws GridException {
+        @Override public Object execute() throws IgniteCheckedException {
             byte status;
             byte[] data;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/jdbc/GridCacheQueryJdbcTask.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/jdbc/GridCacheQueryJdbcTask.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/jdbc/GridCacheQueryJdbcTask.java
index a080192..f70716f 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/jdbc/GridCacheQueryJdbcTask.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/jdbc/GridCacheQueryJdbcTask.java
@@ -53,7 +53,7 @@ public class GridCacheQueryJdbcTask extends ComputeTaskAdapter<byte[], byte[]> {
     private static final ScheduledExecutorService SCHEDULER = Executors.newScheduledThreadPool(1);
 
     /** {@inheritDoc} */
-    @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, byte[] arg) throws GridException {
+    @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, byte[] arg) throws IgniteCheckedException {
         assert arg != null;
 
         Map<String, Object> args = MARSHALLER.unmarshal(arg, null);
@@ -73,7 +73,7 @@ public class GridCacheQueryJdbcTask extends ComputeTaskAdapter<byte[], byte[]> {
                 if (n.id().equals(nodeId))
                     return F.asMap(new JdbcDriverJob(args, first), n);
 
-            throw new GridException("Node doesn't exist or left the grid: " + nodeId);
+            throw new IgniteCheckedException("Node doesn't exist or left the grid: " + nodeId);
         }
         else {
             String cache = (String)args.get("cache");
@@ -82,12 +82,12 @@ public class GridCacheQueryJdbcTask extends ComputeTaskAdapter<byte[], byte[]> {
                 if (U.hasCache(n, cache))
                     return F.asMap(new JdbcDriverJob(args, first), n);
 
-            throw new GridException("Can't find node with cache: " + cache);
+            throw new IgniteCheckedException("Can't find node with cache: " + cache);
         }
     }
 
     /** {@inheritDoc} */
-    @Override public byte[] reduce(List<ComputeJobResult> results) throws GridException {
+    @Override public byte[] reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
         byte status;
         byte[] bytes;
 
@@ -114,7 +114,7 @@ public class GridCacheQueryJdbcTask extends ComputeTaskAdapter<byte[], byte[]> {
     }
 
     /** {@inheritDoc} */
-    @Override public ComputeJobResultPolicy result(ComputeJobResult res, List<ComputeJobResult> rcvd) throws GridException {
+    @Override public ComputeJobResultPolicy result(ComputeJobResult res, List<ComputeJobResult> rcvd) throws IgniteCheckedException {
         return WAIT;
     }
 
@@ -161,7 +161,7 @@ public class GridCacheQueryJdbcTask extends ComputeTaskAdapter<byte[], byte[]> {
         }
 
         /** {@inheritDoc} */
-        @Override public Object execute() throws GridException {
+        @Override public Object execute() throws IgniteCheckedException {
             String cacheName = argument("cache");
             String sql = argument("sql");
             Long timeout = argument("timeout");
@@ -206,7 +206,7 @@ public class GridCacheQueryJdbcTask extends ComputeTaskAdapter<byte[], byte[]> {
                     try {
                         fut.get();
                     }
-                    catch (GridException e) {
+                    catch (IgniteCheckedException e) {
                         if (e.hasCause(SQLException.class))
                             throw new GridInternalException(e.getCause(SQLException.class).getMessage(), e);
                     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/jdbc/GridCacheQueryJdbcValidationTask.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/jdbc/GridCacheQueryJdbcValidationTask.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/jdbc/GridCacheQueryJdbcValidationTask.java
index 4d758f4..0f3b4d9 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/jdbc/GridCacheQueryJdbcValidationTask.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/jdbc/GridCacheQueryJdbcValidationTask.java
@@ -32,7 +32,7 @@ public class GridCacheQueryJdbcValidationTask extends ComputeTaskSplitAdapter<St
 
     /** {@inheritDoc} */
     @Override protected Collection<? extends ComputeJob> split(int gridSize,
-        @Nullable final String cacheName) throws GridException {
+        @Nullable final String cacheName) throws IgniteCheckedException {
         // Register big data usage.
         GridLicenseUseRegistry.onUsage(DATA_GRID, getClass());
 
@@ -51,7 +51,7 @@ public class GridCacheQueryJdbcValidationTask extends ComputeTaskSplitAdapter<St
     }
 
     /** {@inheritDoc} */
-    @Override public Boolean reduce(List<ComputeJobResult> results) throws GridException {
+    @Override public Boolean reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
         return F.first(results).getData();
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/transactions/IgniteTransactionsImpl.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/transactions/IgniteTransactionsImpl.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/transactions/IgniteTransactionsImpl.java
index 621bc50..89bbb74 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/transactions/IgniteTransactionsImpl.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/transactions/IgniteTransactionsImpl.java
@@ -116,14 +116,14 @@ public class IgniteTransactionsImpl<K, V> implements IgniteTransactions {
 
     /** {@inheritDoc} */
     @Override public GridCacheTx txStartAffinity(Object affinityKey, GridCacheTxConcurrency concurrency,
-        GridCacheTxIsolation isolation, long timeout, int txSize) throws IllegalStateException, GridException {
+        GridCacheTxIsolation isolation, long timeout, int txSize) throws IllegalStateException, IgniteCheckedException {
         // TODO: implement.
         return null;
     }
 
     /** {@inheritDoc} */
     @Override public GridCacheTx txStartPartition(int partId, GridCacheTxConcurrency concurrency,
-        GridCacheTxIsolation isolation, long timeout, int txSize) throws IllegalStateException, GridException {
+        GridCacheTxIsolation isolation, long timeout, int txSize) throws IllegalStateException, IgniteCheckedException {
         // TODO: implement.
         return null;
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/clock/GridClockMessage.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/clock/GridClockSyncProcessor.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/clock/GridClockSyncProcessor.java
index e12691f..31b1e14 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/clock/GridClockSyncProcessor.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/clock/GridClockSyncProcessor.java
@@ -9,6 +9,7 @@
 
 package org.gridgain.grid.kernal.processors.clock;
 
+import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.events.*;
 import org.apache.ignite.thread.*;
@@ -18,8 +19,8 @@ import org.gridgain.grid.kernal.managers.communication.*;
 import org.gridgain.grid.kernal.managers.discovery.*;
 import org.gridgain.grid.kernal.managers.eventstorage.*;
 import org.gridgain.grid.kernal.processors.*;
-import org.gridgain.grid.util.typedef.internal.*;
 import org.gridgain.grid.util.*;
+import org.gridgain.grid.util.typedef.internal.*;
 import org.gridgain.grid.util.worker.*;
 
 import java.net.*;
@@ -64,7 +65,7 @@ public class GridClockSyncProcessor extends GridProcessorAdapter {
     }
 
     /** {@inheritDoc} */
-    @Override public void start() throws GridException {
+    @Override public void start() throws IgniteCheckedException {
         super.start();
 
         clockSrc = ctx.timeSource();
@@ -104,7 +105,7 @@ public class GridClockSyncProcessor extends GridProcessorAdapter {
     }
 
     /** {@inheritDoc} */
-    @Override public void addAttributes(Map<String, Object> attrs) throws GridException {
+    @Override public void addAttributes(Map<String, Object> attrs) throws IgniteCheckedException {
         super.addAttributes(attrs);
 
         attrs.put(ATTR_TIME_SERVER_HOST, srv.host());
@@ -112,7 +113,7 @@ public class GridClockSyncProcessor extends GridProcessorAdapter {
     }
 
     /** {@inheritDoc} */
-    @Override public void onKernalStart() throws GridException {
+    @Override public void onKernalStart() throws IgniteCheckedException {
         super.onKernalStart();
 
         srv.afterStart();
@@ -149,7 +150,7 @@ public class GridClockSyncProcessor extends GridProcessorAdapter {
     }
 
     /** {@inheritDoc} */
-    @Override public void stop(boolean cancel) throws GridException {
+    @Override public void stop(boolean cancel) throws IgniteCheckedException {
         super.stop(cancel);
 
         if (srv != null)
@@ -189,7 +190,7 @@ public class GridClockSyncProcessor extends GridProcessorAdapter {
             try {
                 srv.sendPacket(msg, addr, port);
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 U.error(log, "Failed to send time server reply to remote node: " + msg, e);
             }
         }
@@ -291,7 +292,7 @@ public class GridClockSyncProcessor extends GridProcessorAdapter {
                 try {
                     ctx.io().send(n, TOPIC_TIME_SYNC, msg, SYSTEM_POOL);
                 }
-                catch (GridException e) {
+                catch (IgniteCheckedException e) {
                     if (ctx.discovery().pingNode(n.id()))
                         U.error(log, "Failed to send time sync snapshot to remote node (did not leave grid?) " +
                             "[nodeId=" + n.id() + ", msg=" + msg + ", err=" + e.getMessage() + ']');
@@ -426,7 +427,7 @@ public class GridClockSyncProcessor extends GridProcessorAdapter {
 
                     srv.sendPacket(req, addr, port);
                 }
-                catch (GridException e) {
+                catch (IgniteCheckedException e) {
                     LT.warn(log, e, "Failed to send time request to remote node [rmtNodeId=" + rmtNodeId +
                         ", addr=" + addr + ", port=" + port + ']');
                 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/closure/GridClosureProcessor.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/dataload/GridDataLoaderFuture.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/dataload/GridDataLoaderFuture.java
index c9c1390..792895d 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/dataload/GridDataLoaderFuture.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/dataload/GridDataLoaderFuture.java
@@ -49,7 +49,7 @@ class GridDataLoaderFuture extends GridFutureAdapter<Object> {
     }
 
     /** {@inheritDoc} */
-    @Override public boolean cancel() throws GridException {
+    @Override public boolean cancel() throws IgniteCheckedException {
         checkValid();
 
         if (onCancelled()) {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/dataload/GridDataLoaderProcessor.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/dataload/GridDataLoaderProcessor.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/dataload/GridDataLoaderProcessor.java
index 9c5372f..10f0487 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/dataload/GridDataLoaderProcessor.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/dataload/GridDataLoaderProcessor.java
@@ -68,7 +68,7 @@ public class GridDataLoaderProcessor<K, V> extends GridProcessorAdapter {
     }
 
     /** {@inheritDoc} */
-    @Override public void start() throws GridException {
+    @Override public void start() throws IgniteCheckedException {
         if (ctx.config().isDaemon())
             return;
 
@@ -123,7 +123,7 @@ public class GridDataLoaderProcessor<K, V> extends GridProcessorAdapter {
             catch (GridInterruptedException e) {
                 U.warn(log, "Interrupted while waiting for completion of the data loader: " + ldr, e);
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 U.error(log, "Failed to close data loader: " + ldr, e);
             }
         }
@@ -193,7 +193,7 @@ public class GridDataLoaderProcessor<K, V> extends GridProcessorAdapter {
             try {
                 topic = marsh.unmarshal(req.responseTopicBytes(), null);
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 U.error(log, "Failed to unmarshal topic from request: " + req, e);
 
                 return;
@@ -218,7 +218,7 @@ public class GridDataLoaderProcessor<K, V> extends GridProcessorAdapter {
                     sendResponse(nodeId,
                         topic,
                         req.requestId(),
-                        new GridException("Failed to get deployment for request [sndId=" + nodeId +
+                        new IgniteCheckedException("Failed to get deployment for request [sndId=" + nodeId +
                             ", req=" + req + ']'),
                         false);
 
@@ -235,7 +235,7 @@ public class GridDataLoaderProcessor<K, V> extends GridProcessorAdapter {
                 col = marsh.unmarshal(req.collectionBytes(), clsLdr);
                 updater = marsh.unmarshal(req.updaterBytes(), clsLdr);
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 U.error(log, "Failed to unmarshal message [nodeId=" + nodeId + ", req=" + req + ']', e);
 
                 sendResponse(nodeId, topic, req.requestId(), e, false);
@@ -278,7 +278,7 @@ public class GridDataLoaderProcessor<K, V> extends GridProcessorAdapter {
         try {
             errBytes = err != null ? marsh.marshal(err) : null;
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             U.error(log, "Failed to marshal message.", e);
 
             return;
@@ -289,7 +289,7 @@ public class GridDataLoaderProcessor<K, V> extends GridProcessorAdapter {
         try {
             ctx.io().send(nodeId, resTopic, res, PUBLIC_POOL);
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             if (ctx.discovery().alive(nodeId))
                 U.error(log, "Failed to respond to node [nodeId=" + nodeId + ", res=" + res + ']', e);
             else if (log.isDebugEnabled())
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/continuous/GridCacheContinuousQueryEntry.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/continuous/GridCacheContinuousQueryEntry.java
index 6f83ea5..75453ee 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/continuous/GridCacheContinuousQueryEntry.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/continuous/GridCacheContinuousQueryEntry.java
@@ -9,6 +9,7 @@
 
 package org.gridgain.grid.kernal.processors.cache.query.continuous;
 
+import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.marshaller.*;
 import org.gridgain.grid.*;
@@ -113,9 +114,9 @@ public class GridCacheContinuousQueryEntry<K, V> implements GridCacheEntry<K, V>
      *
      * @param marsh Marshaller.
      * @param ldr Class loader.
      * @throws GridException In case of error.
      */
-    void initValue(IgniteMarshaller marsh, @Nullable ClassLoader ldr) throws GridException {
+    void initValue(IgniteMarshaller marsh, @Nullable ClassLoader ldr) throws IgniteCheckedException {
         assert marsh != null;
 
         if (newVal == null && newValBytes != null && !newValBytes.isNull())
@@ -138,9 +139,9 @@ public class GridCacheContinuousQueryEntry<K, V> implements GridCacheEntry<K, V>
 
     /**
      * @param marsh Marshaller.
      * @throws GridException In case of error.
      */
-    void p2pMarshal(IgniteMarshaller marsh) throws GridException {
+    void p2pMarshal(IgniteMarshaller marsh) throws IgniteCheckedException {
         assert marsh != null;
 
         assert key != null;
@@ -159,9 +160,9 @@ public class GridCacheContinuousQueryEntry<K, V> implements GridCacheEntry<K, V>
     /**
      * @param marsh Marshaller.
      * @param ldr Class loader.
      * @throws GridException In case of error.
      */
-    void p2pUnmarshal(IgniteMarshaller marsh, @Nullable ClassLoader ldr) throws GridException {
+    void p2pUnmarshal(IgniteMarshaller marsh, @Nullable ClassLoader ldr) throws IgniteCheckedException {
         assert marsh != null;
 
         assert key == null : "Key should be null: " + key;
@@ -213,7 +214,7 @@ public class GridCacheContinuousQueryEntry<K, V> implements GridCacheEntry<K, V>
     }
 
     /** {@inheritDoc} */
-    @Nullable @Override public V peek(@Nullable Collection<GridCachePeekMode> modes) throws GridException {
+    @Nullable @Override public V peek(@Nullable Collection<GridCachePeekMode> modes) throws IgniteCheckedException {
         assert impl != null;
 
         return impl.peek(modes);
@@ -221,7 +222,7 @@ public class GridCacheContinuousQueryEntry<K, V> implements GridCacheEntry<K, V>
 
     /** {@inheritDoc} */
     @Nullable @Override public V get()
-        throws GridException {
+        throws IgniteCheckedException {
         assert impl != null;
 
         ctx.denyOnFlag(LOCAL);
@@ -239,7 +240,7 @@ public class GridCacheContinuousQueryEntry<K, V> implements GridCacheEntry<K, V>
     }
 
     /** {@inheritDoc} */
-    @Nullable @Override public V reload() throws GridException {
+    @Nullable @Override public V reload() throws IgniteCheckedException {
         assert impl != null;
 
         ctx.denyOnFlag(READ);
@@ -321,7 +322,7 @@ public class GridCacheContinuousQueryEntry<K, V> implements GridCacheEntry<K, V>
 
     /** {@inheritDoc} */
     @Nullable @Override public V set(V val, @Nullable IgnitePredicate<GridCacheEntry<K, V>>... filter)
-        throws GridException {
+        throws IgniteCheckedException {
         assert impl != null;
 
         ctx.denyOnFlag(READ);
@@ -339,7 +340,7 @@ public class GridCacheContinuousQueryEntry<K, V> implements GridCacheEntry<K, V>
     }
 
     /** {@inheritDoc} */
-    @Nullable @Override public V setIfAbsent(V val) throws GridException {
+    @Nullable @Override public V setIfAbsent(V val) throws IgniteCheckedException {
         assert impl != null;
 
         ctx.denyOnFlag(READ);
@@ -358,7 +359,7 @@ public class GridCacheContinuousQueryEntry<K, V> implements GridCacheEntry<K, V>
 
     /** {@inheritDoc} */
     @Override public boolean setx(V val, @Nullable IgnitePredicate<GridCacheEntry<K, V>>... filter)
-        throws GridException {
+        throws IgniteCheckedException {
         assert impl != null;
 
         ctx.denyOnFlag(READ);
@@ -377,7 +378,7 @@ public class GridCacheContinuousQueryEntry<K, V> implements GridCacheEntry<K, V>
     }
 
     /** {@inheritDoc} */
-    @Override public boolean setxIfAbsent(@Nullable V val) throws GridException {
+    @Override public boolean setxIfAbsent(@Nullable V val) throws IgniteCheckedException {
         assert impl != null;
 
         ctx.denyOnFlag(READ);
@@ -395,7 +396,7 @@ public class GridCacheContinuousQueryEntry<K, V> implements GridCacheEntry<K, V>
     }
 
     /** {@inheritDoc} */
-    @Override public void transform(IgniteClosure<V, V> transformer) throws GridException {
+    @Override public void transform(IgniteClosure<V, V> transformer) throws IgniteCheckedException {
         ctx.denyOnFlag(READ);
     }
 
@@ -407,7 +408,7 @@ public class GridCacheContinuousQueryEntry<K, V> implements GridCacheEntry<K, V>
     }
 
     /** {@inheritDoc} */
-    @Nullable @Override public V replace(V val) throws GridException {
+    @Nullable @Override public V replace(V val) throws IgniteCheckedException {
         assert impl != null;
 
         ctx.denyOnFlag(READ);
@@ -425,7 +426,7 @@ public class GridCacheContinuousQueryEntry<K, V> implements GridCacheEntry<K, V>
     }
 
     /** {@inheritDoc} */
-    @Override public boolean replacex(V val) throws GridException {
+    @Override public boolean replacex(V val) throws IgniteCheckedException {
         assert impl != null;
 
         ctx.denyOnFlag(READ);
@@ -443,7 +444,7 @@ public class GridCacheContinuousQueryEntry<K, V> implements GridCacheEntry<K, V>
     }
 
     /** {@inheritDoc} */
-    @Override public boolean replace(V oldVal, V newVal) throws GridException {
+    @Override public boolean replace(V oldVal, V newVal) throws IgniteCheckedException {
         assert impl != null;
 
         ctx.denyOnFlag(READ);
@@ -462,7 +463,7 @@ public class GridCacheContinuousQueryEntry<K, V> implements GridCacheEntry<K, V>
 
     /** {@inheritDoc} */
     @Nullable @Override public V remove(@Nullable IgnitePredicate<GridCacheEntry<K, V>>... filter)
-        throws GridException {
+        throws IgniteCheckedException {
         assert impl != null;
 
         ctx.denyOnFlag(READ);
@@ -480,7 +481,7 @@ public class GridCacheContinuousQueryEntry<K, V> implements GridCacheEntry<K, V>
     }
 
     /** {@inheritDoc} */
-    @Override public boolean removex(@Nullable IgnitePredicate<GridCacheEntry<K, V>>... filter) throws GridException {
+    @Override public boolean removex(@Nullable IgnitePredicate<GridCacheEntry<K, V>>... filter) throws IgniteCheckedException {
         assert impl != null;
 
         ctx.denyOnFlag(READ);
@@ -498,7 +499,7 @@ public class GridCacheContinuousQueryEntry<K, V> implements GridCacheEntry<K, V>
     }
 
     /** {@inheritDoc} */
-    @Override public boolean remove(V val) throws GridException {
+    @Override public boolean remove(V val) throws IgniteCheckedException {
         assert impl != null;
 
         ctx.denyOnFlag(READ);
@@ -535,7 +536,7 @@ public class GridCacheContinuousQueryEntry<K, V> implements GridCacheEntry<K, V>
 
     /** {@inheritDoc} */
     @Override public boolean compact()
-        throws GridException {
+        throws IgniteCheckedException {
         assert impl != null;
 
         ctx.denyOnFlag(READ);
@@ -545,7 +546,7 @@ public class GridCacheContinuousQueryEntry<K, V> implements GridCacheEntry<K, V>
 
     /** {@inheritDoc} */
     @Override public boolean lock(long timeout, @Nullable IgnitePredicate<GridCacheEntry<K, V>>... filter)
-        throws GridException {
+        throws IgniteCheckedException {
         assert impl != null;
 
         return impl.lock(timeout, filter);
@@ -560,7 +561,7 @@ public class GridCacheContinuousQueryEntry<K, V> implements GridCacheEntry<K, V>
     }
 
     /** {@inheritDoc} */
-    @Override public void unlock(IgnitePredicate<GridCacheEntry<K, V>>... filter) throws GridException {
+    @Override public void unlock(IgnitePredicate<GridCacheEntry<K, V>>... filter) throws IgniteCheckedException {
         assert impl != null;
 
         impl.unlock(filter);
@@ -574,7 +575,7 @@ public class GridCacheContinuousQueryEntry<K, V> implements GridCacheEntry<K, V>
     }
 
     /** {@inheritDoc} */
-    @Override public int memorySize() throws GridException {
+    @Override public int memorySize() throws IgniteCheckedException {
         assert impl != null;
 
         return impl.memorySize();

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/continuous/GridCacheContinuousQueryHandler.java
----------------------------------------------------------------------
@@ -113,9 +114,9 @@ public class GridCacheContinuousQueryEntry<K, V> implements GridCacheEntry<K, V>
      * @param marsh Marshaller.
      * @param ldr Class loader.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
@@ -138,9 +139,9 @@ public class GridCacheContinuousQueryEntry<K, V> implements GridCacheEntry<K, V>
     /**
      * @param marsh Marshaller.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
@@ -159,9 +160,9 @@ public class GridCacheContinuousQueryEntry<K, V> implements GridCacheEntry<K, V>
      * @param marsh Marshaller.
      * @param ldr Class loader.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/continuous/GridCacheContinuousQueryHandler.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/continuous/GridCacheContinuousQueryHandler.java
index 672258d..9d810c0 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/continuous/GridCacheContinuousQueryHandler.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/continuous/GridCacheContinuousQueryHandler.java
@@ -9,6 +9,7 @@
 
 package org.gridgain.grid.kernal.processors.cache.query.continuous;
 
+import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.events.*;
 import org.apache.ignite.lang.*;
@@ -107,7 +108,7 @@ class GridCacheContinuousQueryHandler<K, V> implements GridContinuousHandler {
 
     /** {@inheritDoc} */
     @Override public boolean register(final UUID nodeId, final UUID routineId, final GridKernalContext ctx)
-        throws GridException {
+        throws IgniteCheckedException {
         assert nodeId != null;
         assert routineId != null;
         assert ctx != null;
@@ -177,7 +178,7 @@ class GridCacheContinuousQueryHandler<K, V> implements GridContinuousHandler {
 
                             ctx.continuous().addNotification(nodeId, routineId, e, topic);
                         }
-                        catch (GridException ex) {
+                        catch (IgniteCheckedException ex) {
                             U.error(ctx.log(getClass()), "Failed to send event notification to node: " + nodeId, ex);
                         }
                     }
@@ -306,7 +307,7 @@ class GridCacheContinuousQueryHandler<K, V> implements GridContinuousHandler {
                 try {
                     qe.p2pUnmarshal(ctx.config().getMarshaller(), ldr);
                 }
-                catch (GridException ex) {
+                catch (IgniteCheckedException ex) {
                     U.error(ctx.log(getClass()), "Failed to unmarshal entry.", ex);
                 }
             }
@@ -317,7 +318,7 @@ class GridCacheContinuousQueryHandler<K, V> implements GridContinuousHandler {
     }
 
     /** {@inheritDoc} */
-    @Override public void p2pMarshal(GridKernalContext ctx) throws GridException {
+    @Override public void p2pMarshal(GridKernalContext ctx) throws IgniteCheckedException {
         assert ctx != null;
         assert ctx.config().isPeerClassLoadingEnabled();
 
@@ -329,7 +330,7 @@ class GridCacheContinuousQueryHandler<K, V> implements GridContinuousHandler {
     }
 
     /** {@inheritDoc} */
-    @Override public void p2pUnmarshal(UUID nodeId, GridKernalContext ctx) throws GridException {
+    @Override public void p2pUnmarshal(UUID nodeId, GridKernalContext ctx) throws IgniteCheckedException {
         assert nodeId != null;
         assert ctx != null;
         assert ctx.config().isPeerClassLoadingEnabled();
@@ -431,9 +432,9 @@ class GridCacheContinuousQueryHandler<K, V> implements GridContinuousHandler {
         /**
          * @param obj Object.
          * @param ctx Kernal context.
          * @throws GridException In case of error.
          */
-        private DeployableObject(Object obj, GridKernalContext ctx) throws GridException {
+        private DeployableObject(Object obj, GridKernalContext ctx) throws IgniteCheckedException {
             assert obj != null;
             assert ctx != null;
 
@@ -455,9 +456,9 @@ class GridCacheContinuousQueryHandler<K, V> implements GridContinuousHandler {
          * @param nodeId Node ID.
          * @param ctx Kernal context.
          * @return Deserialized object.
          * @throws GridException In case of error.
          */
-        <T> T unmarshal(UUID nodeId, GridKernalContext ctx) throws GridException {
+        <T> T unmarshal(UUID nodeId, GridKernalContext ctx) throws IgniteCheckedException {
             assert ctx != null;
 
             GridDeployment dep = ctx.deploy().getGlobalDeployment(depInfo.deployMode(), clsName, clsName,

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/continuous/GridCacheContinuousQueryManager.java
----------------------------------------------------------------------
@@ -431,9 +432,9 @@ class GridCacheContinuousQueryHandler<K, V> implements GridContinuousHandler {
          * @param obj Object.
          * @param ctx Kernal context.
-         * @throws GridException In case of error.
+         * @throws IgniteCheckedException In case of error.
          */
@@ -455,9 +456,9 @@ class GridCacheContinuousQueryHandler<K, V> implements GridContinuousHandler {
          * @param ctx Kernal context.
          * @return Deserialized object.
-         * @throws GridException In case of error.
+         * @throws IgniteCheckedException In case of error.
          */
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/continuous/GridCacheContinuousQueryManager.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/continuous/GridCacheContinuousQueryManager.java
index 55ea9d1..c428dad 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/continuous/GridCacheContinuousQueryManager.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/continuous/GridCacheContinuousQueryManager.java
@@ -9,9 +9,9 @@
 
 package org.gridgain.grid.kernal.processors.cache.query.continuous;
 
+import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.cache.*;
 import org.gridgain.grid.cache.query.*;
 import org.gridgain.grid.kernal.processors.cache.*;
@@ -49,19 +49,19 @@ public class GridCacheContinuousQueryManager<K, V> extends GridCacheManagerAdapt
     private final AtomicLong seq = new AtomicLong();
 
     /** {@inheritDoc} */
-    @Override protected void start0() throws GridException {
+    @Override protected void start0() throws IgniteCheckedException {
         // Append cache name to the topic.
         topicPrefix = "CONTINUOUS_QUERY" + (cctx.name() == null ? "" : "_" + cctx.name());
     }
 
     /** {@inheritDoc} */
-    @Override protected void onKernalStart0() throws GridException {
+    @Override protected void onKernalStart0() throws IgniteCheckedException {
         if (intLsnrCnt.get() > 0 || lsnrCnt.get() > 0) {
             Collection<ClusterNode> nodes = cctx.discovery().cacheNodes(cctx.name(), -1);
 
             for (ClusterNode n : nodes) {
                 if (!n.version().greaterThanEqual(6, 2, 0))
-                    throw new GridException("Rolling update is not supported for continuous queries " +
+                    throw new IgniteCheckedException("Rolling update is not supported for continuous queries " +
                         "for versions below 6.2.0");
             }
         }
@@ -84,10 +84,10 @@ public class GridCacheContinuousQueryManager<K, V> extends GridCacheManagerAdapt
      * @param newBytes New value bytes.
      * @param oldVal Old value.
      * @param oldBytes Old value bytes.
      * @throws GridException In case of error.
      */
     public void onEntryUpdate(GridCacheEntryEx<K, V> e, K key, @Nullable V newVal,
-        @Nullable GridCacheValueBytes newBytes, V oldVal, @Nullable GridCacheValueBytes oldBytes) throws GridException {
+        @Nullable GridCacheValueBytes newBytes, V oldVal, @Nullable GridCacheValueBytes oldBytes) throws IgniteCheckedException {
         assert e != null;
         assert key != null;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/query/jdbc/GridCacheQueryJdbcMetadataTask.java
----------------------------------------------------------------------
@@ -84,10 +84,10 @@ public class GridCacheContinuousQueryManager<K, V> extends GridCacheManagerAdapt
      * @param oldVal Old value.
      * @param oldBytes Old value bytes.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     public void onEntryUpdate(GridCacheEntryEx<K, V> e, K key, @Nullable V newVal,
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/clock/GridClockMessage.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/clock/GridClockMessage.java
index 552c91c..4907a5f 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/clock/GridClockMessage.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/clock/GridClockMessage.java
@@ -9,7 +9,7 @@
 
 package org.gridgain.grid.kernal.processors.clock;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.gridgain.grid.util.typedef.internal.*;
 
 import java.util.*;
@@ -134,11 +134,11 @@ public class GridClockMessage {
      * @param off Offset.
      * @param len Packet length.
      * @return Assembled message.
      * @throws GridException If message length is invalid.
      */
-    public static GridClockMessage fromBytes(byte[] buf, int off, int len) throws GridException {
+    public static GridClockMessage fromBytes(byte[] buf, int off, int len) throws IgniteCheckedException {
         if (len < PACKET_SIZE)
-            throw new GridException("Failed to assemble time server packet (message is too short).");
+            throw new IgniteCheckedException("Failed to assemble time server packet (message is too short).");
 
         long lsb = U.bytesToLong(buf, off);
         long msb = U.bytesToLong(buf, off + 8);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/clock/GridClockServer.java
----------------------------------------------------------------------
@@ -134,11 +134,11 @@ public class GridClockMessage {
      * @param len Packet length.
      * @return Assembled message.
-     * @throws GridException If message length is invalid.
+     * @throws IgniteCheckedException If message length is invalid.
      */
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/clock/GridClockServer.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/clock/GridClockServer.java
index ce30919..60ef4c7 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/clock/GridClockServer.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/clock/GridClockServer.java
@@ -43,9 +43,9 @@ public class GridClockServer {
      * Starts server.
      *
      * @param ctx Kernal context.
      * @throws GridException If server could not be started.
      */
-    public void start(GridKernalContext ctx) throws GridException {
+    public void start(GridKernalContext ctx) throws IgniteCheckedException {
         this.ctx = ctx;
 
         clockSync = ctx.clockSync();
@@ -76,11 +76,11 @@ public class GridClockServer {
             }
 
             if (sock == null)
-                throw new GridException("Failed to bind time server socket within specified port range [locHost=" +
+                throw new IgniteCheckedException("Failed to bind time server socket within specified port range [locHost=" +
                     locHost + ", startPort=" + startPort + ", endPort=" + endPort + ']');
         }
         catch (IOException e) {
-            throw new GridException("Failed to start time server (failed to get local host address)", e);
+            throw new IgniteCheckedException("Failed to start time server (failed to get local host address)", e);
         }
     }
 
@@ -123,9 +123,9 @@ public class GridClockServer {
      * @param msg Message to send.
      * @param addr Address.
      * @param port Port.
      * @throws GridException If send failed.
      */
-    public void sendPacket(GridClockMessage msg, InetAddress addr, int port) throws GridException {
+    public void sendPacket(GridClockMessage msg, InetAddress addr, int port) throws IgniteCheckedException {
         try {
             DatagramPacket packet = new DatagramPacket(msg.toBytes(), GridClockMessage.PACKET_SIZE, addr, port);
 
@@ -136,7 +136,7 @@ public class GridClockServer {
         }
         catch (IOException e) {
             if (!sock.isClosed())
-                throw new GridException("Failed to send datagram message to remote node [addr=" + addr +
+                throw new IgniteCheckedException("Failed to send datagram message to remote node [addr=" + addr +
                     ", port=" + port + ", msg=" + msg + ']', e);
         }
     }
@@ -185,7 +185,7 @@ public class GridClockServer {
 
                     clockSync.onMessageReceived(msg, packet.getAddress(), packet.getPort());
                 }
-                catch (GridException e) {
+                catch (IgniteCheckedException e) {
                     U.warn(log, "Failed to assemble clock server message (will ignore the packet) [host=" +
                         packet.getAddress() + ", port=" + packet.getPort() + ", err=" + e.getMessage() + ']');
                 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/clock/GridClockSyncProcessor.java
----------------------------------------------------------------------
@@ -43,9 +43,9 @@ public class GridClockServer {
      *
      * @param ctx Kernal context.
-     * @throws GridException If server could not be started.
+     * @throws IgniteCheckedException If server could not be started.
      */
@@ -123,9 +123,9 @@ public class GridClockServer {
      * @param addr Address.
      * @param port Port.
-     * @throws GridException If send failed.
+     * @throws IgniteCheckedException If send failed.
      */
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/closure/GridClosureProcessor.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/closure/GridClosureProcessor.java
index 72fb0f1..f19327e 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/closure/GridClosureProcessor.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/closure/GridClosureProcessor.java
@@ -9,12 +9,12 @@
 
 package org.gridgain.grid.kernal.processors.closure;
 
+import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.compute.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.marshaller.*;
 import org.apache.ignite.resources.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.cache.*;
 import org.gridgain.grid.cache.affinity.*;
 import org.gridgain.grid.kernal.*;
@@ -65,7 +65,7 @@ public class GridClosureProcessor extends GridProcessorAdapter {
     }
 
     /** {@inheritDoc} */
-    @Override public void start() throws GridException {
+    @Override public void start() throws IgniteCheckedException {
         if (log.isDebugEnabled())
             log.debug("Started closure processor.");
     }
@@ -195,11 +195,11 @@ public class GridClosureProcessor extends GridProcessorAdapter {
      * @param jobs Closures to map.
      * @param nodes Grid nodes.
      * @param lb Load balancer.
      * @throws GridException Thrown in case of any errors.
      * @return Mapping.
      */
     private Map<ComputeJob, ClusterNode> absMap(GridClosureCallMode mode, Collection<? extends Runnable> jobs,
-        Collection<ClusterNode> nodes, ComputeLoadBalancer lb) throws GridException {
+        Collection<ClusterNode> nodes, ComputeLoadBalancer lb) throws IgniteCheckedException {
         assert mode != null;
         assert jobs != null;
         assert nodes != null;
@@ -243,12 +243,12 @@ public class GridClosureProcessor extends GridProcessorAdapter {
      * @param jobs Closures to map.
      * @param nodes Grid nodes.
      * @param lb Load balancer.
      * @throws GridException Thrown in case of any errors.
      * @return Mapping.
      */
     private <R> Map<ComputeJob, ClusterNode> outMap(GridClosureCallMode mode,
         Collection<? extends Callable<R>> jobs, Collection<ClusterNode> nodes, ComputeLoadBalancer lb)
-        throws GridException {
+        throws IgniteCheckedException {
         assert mode != null;
         assert jobs != null;
         assert nodes != null;
@@ -397,7 +397,7 @@ public class GridClosureProcessor extends GridProcessorAdapter {
 
             return ctx.task().execute(new T5<>(cacheName, affKey0, job), null, false);
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             return new GridFinishedFuture<>(ctx, e);
         }
         finally {
@@ -427,7 +427,7 @@ public class GridClosureProcessor extends GridProcessorAdapter {
 
             return ctx.task().execute(new T4(cacheName, affKey0, job), null, false);
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             return new GridFinishedFuture<>(ctx, e);
         }
         finally {
@@ -693,9 +693,9 @@ public class GridClosureProcessor extends GridProcessorAdapter {
      * @param c Closure to execute.
      * @param sys If {@code true}, then system pool will be used, otherwise public pool will be used.
      * @return Future.
      * @throws GridException Thrown in case of any errors.
      */
-    private IgniteFuture<?> runLocal(@Nullable final Runnable c, boolean sys) throws GridException {
+    private IgniteFuture<?> runLocal(@Nullable final Runnable c, boolean sys) throws IgniteCheckedException {
         return runLocal(c, sys ? GridClosurePolicy.SYSTEM_POOL : GridClosurePolicy.PUBLIC_POOL);
     }
 
@@ -703,9 +703,9 @@ public class GridClosureProcessor extends GridProcessorAdapter {
      * @param c Closure to execute.
      * @param plc Whether to run on system or public pool.
      * @return Future.
      * @throws GridException Thrown in case of any errors.
      */
-    private IgniteFuture<?> runLocal(@Nullable final Runnable c, GridClosurePolicy plc) throws GridException {
+    private IgniteFuture<?> runLocal(@Nullable final Runnable c, GridClosurePolicy plc) throws IgniteCheckedException {
         if (c == null)
             return new GridFinishedFuture(ctx);
 
@@ -829,9 +829,9 @@ public class GridClosureProcessor extends GridProcessorAdapter {
      * @param c Closure to execute.
      * @param sys If {@code true}, then system pool will be used, otherwise public pool will be used.
      * @return Future.
      * @throws GridException Thrown in case of any errors.
      */
-    private <R> IgniteFuture<R> callLocal(@Nullable final Callable<R> c, boolean sys) throws GridException {
+    private <R> IgniteFuture<R> callLocal(@Nullable final Callable<R> c, boolean sys) throws IgniteCheckedException {
         return callLocal(c, sys ? GridClosurePolicy.SYSTEM_POOL : GridClosurePolicy.PUBLIC_POOL);
     }
 
@@ -840,9 +840,9 @@ public class GridClosureProcessor extends GridProcessorAdapter {
      * @param plc Whether to run on system or public pool.
      * @param <R> Type of closure return value.
      * @return Future.
      * @throws GridException Thrown in case of any errors.
      */
-    private <R> IgniteFuture<R> callLocal(@Nullable final Callable<R> c, GridClosurePolicy plc) throws GridException {
+    private <R> IgniteFuture<R> callLocal(@Nullable final Callable<R> c, GridClosurePolicy plc) throws IgniteCheckedException {
         if (c == null)
             return new GridFinishedFuture<>(ctx);
 
@@ -933,7 +933,7 @@ public class GridClosureProcessor extends GridProcessorAdapter {
         try {
             return callLocal(c, plc);
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             // If execution was rejected - rerun locally.
             if (e.getCause() instanceof RejectedExecutionException) {
                 U.warn(log, "Closure execution has been rejected (will execute in the same thread) [plc=" + plc +
@@ -969,7 +969,7 @@ public class GridClosureProcessor extends GridProcessorAdapter {
                     return job.apply(arg);
                 }
 
-                @Override public void onMasterNodeLeft(ComputeTaskSession ses) throws GridException {
+                @Override public void onMasterNodeLeft(ComputeTaskSession ses) throws IgniteCheckedException {
                     ((ComputeJobMasterLeaveAware)job).onMasterNodeLeft(ses);
                 }
             };
@@ -1000,11 +1000,11 @@ public class GridClosureProcessor extends GridProcessorAdapter {
                         return c.call();
                     }
                     catch (Exception e) {
-                        throw new GridRuntimeException(e);
+                        throw new IgniteException(e);
                     }
                 }
 
-                @Override public void onMasterNodeLeft(ComputeTaskSession ses) throws GridException {
+                @Override public void onMasterNodeLeft(ComputeTaskSession ses) throws IgniteCheckedException {
                     ((ComputeJobMasterLeaveAware)c).onMasterNodeLeft(ses);
                 }
             };
@@ -1016,7 +1016,7 @@ public class GridClosureProcessor extends GridProcessorAdapter {
                         return c.call();
                     }
                     catch (Exception e) {
-                        throw new GridRuntimeException(e);
+                        throw new IgniteException(e);
                     }
                 }
             };
@@ -1050,11 +1050,11 @@ public class GridClosureProcessor extends GridProcessorAdapter {
                         return c.call();
                     }
                     catch (Exception e) {
-                        throw new GridRuntimeException(e);
+                        throw new IgniteException(e);
                     }
                 }
 
-                @Override public void onMasterNodeLeft(ComputeTaskSession ses) throws GridException {
+                @Override public void onMasterNodeLeft(ComputeTaskSession ses) throws IgniteCheckedException {
                     ((ComputeJobMasterLeaveAware)c).onMasterNodeLeft(ses);
                 }
             };
@@ -1074,7 +1074,7 @@ public class GridClosureProcessor extends GridProcessorAdapter {
                         return c.call();
                     }
                     catch (Exception e) {
-                        throw new GridRuntimeException(e);
+                        throw new IgniteException(e);
                     }
                 }
             };
@@ -1099,7 +1099,7 @@ public class GridClosureProcessor extends GridProcessorAdapter {
                     return null;
                 }
 
-                @Override public void onMasterNodeLeft(ComputeTaskSession ses) throws GridException {
+                @Override public void onMasterNodeLeft(ComputeTaskSession ses) throws IgniteCheckedException {
                     ((ComputeJobMasterLeaveAware)r).onMasterNodeLeft(ses);
                 }
             };
@@ -1143,7 +1143,7 @@ public class GridClosureProcessor extends GridProcessorAdapter {
                     return null;
                 }
 
-                @Override public void onMasterNodeLeft(ComputeTaskSession ses) throws GridException {
+                @Override public void onMasterNodeLeft(ComputeTaskSession ses) throws IgniteCheckedException {
                     ((ComputeJobMasterLeaveAware)r).onMasterNodeLeft(ses);
                 }
             };
@@ -1188,9 +1188,9 @@ public class GridClosureProcessor extends GridProcessorAdapter {
         /**
          * @param job Job.
          * @param node Node.
          * @throws GridException In case of error.
          */
-        public void map(ComputeJob job, ClusterNode node) throws GridException {
+        public void map(ComputeJob job, ClusterNode node) throws IgniteCheckedException {
             assert job != null;
             assert node != null;
 
@@ -1223,7 +1223,7 @@ public class GridClosureProcessor extends GridProcessorAdapter {
         }
 
         /** {@inheritDoc} */
-        @Nullable @Override public Void reduce(List<ComputeJobResult> results) throws GridException {
+        @Nullable @Override public Void reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             return null;
         }
     }
@@ -1258,7 +1258,7 @@ public class GridClosureProcessor extends GridProcessorAdapter {
 
         /** {@inheritDoc} */
         @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, @Nullable Void arg)
-            throws GridException {
+            throws IgniteCheckedException {
             return absMap(t.get1(), t.get2(), subgrid, lb);
         }
     }
@@ -1290,7 +1290,7 @@ public class GridClosureProcessor extends GridProcessorAdapter {
 
         /** {@inheritDoc} */
         @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, @Nullable Void arg)
-            throws GridException {
+            throws IgniteCheckedException {
             return absMap(t.get1(), F.asList(t.get2()), subgrid, lb);
         }
     }
@@ -1331,13 +1331,13 @@ public class GridClosureProcessor extends GridProcessorAdapter {
 
         /** {@inheritDoc} */
         @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, @Nullable Void arg)
-            throws GridException {
+            throws IgniteCheckedException {
             return outMap(t.get1(), t.get2(), subgrid, lb);
         }
 
         /** {@inheritDoc} */
         @Override public ComputeJobResultPolicy result(ComputeJobResult res, List<ComputeJobResult> rcvd)
-            throws GridException {
+            throws IgniteCheckedException {
             ComputeJobResultPolicy resPlc = super.result(res, rcvd);
 
             if (res.getException() == null && resPlc != FAILOVER && !t.get3().collect((R1)res.getData()))
@@ -1386,7 +1386,7 @@ public class GridClosureProcessor extends GridProcessorAdapter {
 
         /** {@inheritDoc} */
         @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, @Nullable Void arg)
-            throws GridException {
+            throws IgniteCheckedException {
             ComputeJob job = job(this.job, cacheName, affKey);
 
             return Collections.singletonMap(job, lb.getBalancedNode(job, null));
@@ -1427,20 +1427,20 @@ public class GridClosureProcessor extends GridProcessorAdapter {
 
         /** {@inheritDoc} */
         @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, @Nullable Void arg)
-            throws GridException {
+            throws IgniteCheckedException {
             ComputeJob job = job(this.job, cacheName, affKey);
 
             return Collections.singletonMap(job, lb.getBalancedNode(job, null));
         }
 
         /** {@inheritDoc} */
-        @Override public R reduce(List<ComputeJobResult> res) throws GridException {
+        @Override public R reduce(List<ComputeJobResult> res) throws IgniteCheckedException {
             for (ComputeJobResult r : res) {
                 if (r.getException() == null)
                     return r.getData();
             }
 
-            throw new GridException("Failed to find successful job result: " + res);
+            throw new IgniteCheckedException("Failed to find successful job result: " + res);
         }
     }
 
@@ -1478,7 +1478,7 @@ public class GridClosureProcessor extends GridProcessorAdapter {
 
         /** {@inheritDoc} */
         @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, @Nullable Void arg)
-            throws GridException {
+            throws IgniteCheckedException {
             return outMap(mode, jobs, subgrid, lb);
         }
 
@@ -1515,17 +1515,17 @@ public class GridClosureProcessor extends GridProcessorAdapter {
 
         /** {@inheritDoc} */
         @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, @Nullable Void arg)
-            throws GridException {
+            throws IgniteCheckedException {
             return outMap(t.get1(), F.asList(t.get2()), subgrid, lb);
         }
 
         /** {@inheritDoc} */
-        @Override public R reduce(List<ComputeJobResult> res) throws GridException {
+        @Override public R reduce(List<ComputeJobResult> res) throws IgniteCheckedException {
             for (ComputeJobResult r : res)
                 if (r.getException() == null)
                     return r.getData();
 
-            throw new GridException("Failed to find successful job result: " + res);
+            throw new IgniteCheckedException("Failed to find successful job result: " + res);
         }
     }
 
@@ -1558,19 +1558,19 @@ public class GridClosureProcessor extends GridProcessorAdapter {
 
         /** {@inheritDoc} */
         @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, @Nullable Void arg)
-            throws GridException {
+            throws IgniteCheckedException {
             ComputeJob job = job(this.job, this.arg);
 
             return Collections.singletonMap(job, lb.getBalancedNode(job, null));
         }
 
         /** {@inheritDoc} */
-        @Override public R reduce(List<ComputeJobResult> res) throws GridException {
+        @Override public R reduce(List<ComputeJobResult> res) throws IgniteCheckedException {
             for (ComputeJobResult r : res)
                 if (r.getException() == null)
                     return r.getData();
 
-            throw new GridException("Failed to find successful job result: " + res);
+            throw new IgniteCheckedException("Failed to find successful job result: " + res);
         }
     }
 
@@ -1603,7 +1603,7 @@ public class GridClosureProcessor extends GridProcessorAdapter {
 
         /** {@inheritDoc} */
         @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, @Nullable Void arg)
-            throws GridException {
+            throws IgniteCheckedException {
             Map<ComputeJob, ClusterNode> map = new HashMap<>(args.size(), 1);
 
             JobMapper mapper = new JobMapper(map);
@@ -1618,7 +1618,7 @@ public class GridClosureProcessor extends GridProcessorAdapter {
         }
 
         /** {@inheritDoc} */
-        @Override public Collection<R> reduce(List<ComputeJobResult> res) throws GridException {
+        @Override public Collection<R> reduce(List<ComputeJobResult> res) throws IgniteCheckedException {
             return F.jobResults(res);
         }
     }
@@ -1657,7 +1657,7 @@ public class GridClosureProcessor extends GridProcessorAdapter {
 
         /** {@inheritDoc} */
         @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, @Nullable Void arg)
-            throws GridException {
+            throws IgniteCheckedException {
             Map<ComputeJob, ClusterNode> map = new HashMap<>(args.size(), 1);
 
             JobMapper mapper = new JobMapper(map);
@@ -1673,7 +1673,7 @@ public class GridClosureProcessor extends GridProcessorAdapter {
 
         /** {@inheritDoc} */
         @Override public ComputeJobResultPolicy result(ComputeJobResult res, List<ComputeJobResult> rcvd)
-            throws GridException {
+            throws IgniteCheckedException {
             ComputeJobResultPolicy resPlc = super.result(res, rcvd);
 
             if (res.getException() == null && resPlc != FAILOVER && !rdc.collect((R1) res.getData()))
@@ -1683,7 +1683,7 @@ public class GridClosureProcessor extends GridProcessorAdapter {
         }
 
         /** {@inheritDoc} */
-        @Override public R2 reduce(List<ComputeJobResult> res) throws GridException {
+        @Override public R2 reduce(List<ComputeJobResult> res) throws IgniteCheckedException {
             return rdc.reduce();
         }
     }
@@ -1714,7 +1714,7 @@ public class GridClosureProcessor extends GridProcessorAdapter {
 
         /** {@inheritDoc} */
         @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, @Nullable Void arg)
-            throws GridException {
+            throws IgniteCheckedException {
             if (F.isEmpty(subgrid))
                 return Collections.emptyMap();
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/continuous/GridContinuousHandler.java
----------------------------------------------------------------------
@@ -195,11 +195,11 @@ public class GridClosureProcessor extends GridProcessorAdapter {
      * @param nodes Grid nodes.
      * @param lb Load balancer.
-     * @throws GridException Thrown in case of any errors.
+     * @throws IgniteCheckedException Thrown in case of any errors.
      * @return Mapping.
      */
@@ -243,12 +243,12 @@ public class GridClosureProcessor extends GridProcessorAdapter {
      * @param nodes Grid nodes.
      * @param lb Load balancer.
-     * @throws GridException Thrown in case of any errors.
+     * @throws IgniteCheckedException Thrown in case of any errors.
      * @return Mapping.
      */
@@ -693,9 +693,9 @@ public class GridClosureProcessor extends GridProcessorAdapter {
      * @param sys If {@code true}, then system pool will be used, otherwise public pool will be used.
      * @return Future.
-     * @throws GridException Thrown in case of any errors.
+     * @throws IgniteCheckedException Thrown in case of any errors.
      */
@@ -703,9 +703,9 @@ public class GridClosureProcessor extends GridProcessorAdapter {
      * @param plc Whether to run on system or public pool.
      * @return Future.
-     * @throws GridException Thrown in case of any errors.
+     * @throws IgniteCheckedException Thrown in case of any errors.
      */
@@ -829,9 +829,9 @@ public class GridClosureProcessor extends GridProcessorAdapter {
      * @param sys If {@code true}, then system pool will be used, otherwise public pool will be used.
      * @return Future.
-     * @throws GridException Thrown in case of any errors.
+     * @throws IgniteCheckedException Thrown in case of any errors.
      */
@@ -840,9 +840,9 @@ public class GridClosureProcessor extends GridProcessorAdapter {
      * @param <R> Type of closure return value.
      * @return Future.
-     * @throws GridException Thrown in case of any errors.
+     * @throws IgniteCheckedException Thrown in case of any errors.
      */
@@ -1188,9 +1188,9 @@ public class GridClosureProcessor extends GridProcessorAdapter {
          * @param job Job.
          * @param node Node.
-         * @throws GridException In case of error.
+         * @throws IgniteCheckedException In case of error.
          */
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/continuous/GridContinuousHandler.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/continuous/GridContinuousHandler.java
index 7b20694..2855040 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/continuous/GridContinuousHandler.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/continuous/GridContinuousHandler.java
@@ -9,7 +9,7 @@
 
 package org.gridgain.grid.kernal.processors.continuous;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.gridgain.grid.kernal.*;
 import org.jetbrains.annotations.*;
 
@@ -27,9 +27,9 @@ public interface GridContinuousHandler extends Externalizable {
      * @param routineId Routine ID.
      * @param ctx Kernal context.
      * @return Whether listener was actually registered.
      * @throws GridException In case of error.
      */
-    public boolean register(UUID nodeId, UUID routineId, GridKernalContext ctx) throws GridException;
+    public boolean register(UUID nodeId, UUID routineId, GridKernalContext ctx) throws IgniteCheckedException;
 
     /**
      * Callback called after listener is registered and acknowledgement is sent.
@@ -61,18 +61,18 @@ public interface GridContinuousHandler extends Externalizable {
      * Deploys and marshals inner objects (called only if peer deployment is enabled).
      *
      * @param ctx Kernal context.
      * @throws GridException In case of error.
      */
-    public void p2pMarshal(GridKernalContext ctx) throws GridException;
+    public void p2pMarshal(GridKernalContext ctx) throws IgniteCheckedException;
 
     /**
      * Unmarshals inner objects (called only if peer deployment is enabled).
      *
      * @param nodeId Sender node ID.
      * @param ctx Kernal context.
      * @throws GridException In case of error.
      */
-    public void p2pUnmarshal(UUID nodeId, GridKernalContext ctx) throws GridException;
+    public void p2pUnmarshal(UUID nodeId, GridKernalContext ctx) throws IgniteCheckedException;
 
     /**
      * @return Topic for ordered notifications. If {@code null}, notifications

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/continuous/GridContinuousProcessor.java
----------------------------------------------------------------------
@@ -27,9 +27,9 @@ public interface GridContinuousHandler extends Externalizable {
      * @param ctx Kernal context.
      * @return Whether listener was actually registered.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
@@ -61,18 +61,18 @@ public interface GridContinuousHandler extends Externalizable {
      *
      * @param ctx Kernal context.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
@@ -61,18 +61,18 @@ public interface GridContinuousHandler extends Externalizable {
      * @param nodeId Sender node ID.
      * @param ctx Kernal context.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/continuous/GridContinuousProcessor.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/continuous/GridContinuousProcessor.java
index a0e5fe3..14d89f3 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/continuous/GridContinuousProcessor.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/continuous/GridContinuousProcessor.java
@@ -9,6 +9,7 @@
 
 package org.gridgain.grid.kernal.processors.continuous;
 
+import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.events.*;
 import org.apache.ignite.lang.*;
@@ -97,7 +98,7 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
     }
 
     /** {@inheritDoc} */
-    @Override public void start() throws GridException {
+    @Override public void start() throws IgniteCheckedException {
         if (ctx.config().isDaemon())
             return;
 
@@ -153,7 +154,7 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
                                     log.debug("Failed to send pending start request to node (is node alive?): " +
                                         nodeId);
                             }
-                            catch (GridException e) {
+                            catch (IgniteCheckedException e) {
                                 U.error(log, "Failed to send pending start request to node: " + nodeId, e);
 
                                 completeStartFuture(routineId);
@@ -221,7 +222,7 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
                     try {
                         msg.data(marsh.unmarshal(msg.dataBytes(), null));
                     }
-                    catch (GridException e) {
+                    catch (IgniteCheckedException e) {
                         U.error(log, "Failed to process message (ignoring): " + msg, e);
 
                         return;
@@ -265,7 +266,7 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
     }
 
     /** {@inheritDoc} */
-    @Override public void stop(boolean cancel) throws GridException {
+    @Override public void stop(boolean cancel) throws IgniteCheckedException {
         if (ctx.config().isDaemon())
             return;
 
@@ -325,7 +326,7 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
                             item.autoUnsubscribe, false))
                             item.hnd.onListenerRegistered(item.routineId, ctx);
                     }
-                    catch (GridException e) {
+                    catch (IgniteCheckedException e) {
                         U.error(log, "Failed to register continuous handler.", e);
                     }
                 }
@@ -379,7 +380,7 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
                 hnd.p2pMarshal(ctx);
             }
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             return new GridFinishedFuture<>(ctx, e);
         }
 
@@ -396,7 +397,7 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
                         try {
                             msg.data(marsh.unmarshal(msg.dataBytes(), null));
                         }
-                        catch (GridException e) {
+                        catch (IgniteCheckedException e) {
                             U.error(log, "Failed to process message (ignoring): " + msg, e);
 
                             return;
@@ -465,7 +466,7 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
                         // Stop routine with exception. Continue and complete
                         // future otherwise.
                         if (!ids.isEmpty()) {
-                            f.onDone(new GridException("Failed to get start acknowledgement from nodes (timeout " +
+                            f.onDone(new IgniteCheckedException("Failed to get start acknowledgement from nodes (timeout " +
                                 "expired): " + ids + ". Will unregister all continuous listeners."));
 
                             stopRoutine(routineId);
@@ -487,7 +488,7 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
 
                 sendWithRetries(nodes, req, null);
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 startFuts.remove(routineId);
                 waitForStartAck.remove(routineId);
 
@@ -512,9 +513,9 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
                 if (registerHandler(ctx.localNodeId(), routineId, hnd, bufSize, interval, autoUnsubscribe, true))
                     hnd.onListenerRegistered(routineId, ctx);
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 return new GridFinishedFuture<>(ctx,
-                    new GridException("Failed to register handler locally: " + hnd, e));
+                    new IgniteCheckedException("Failed to register handler locally: " + hnd, e));
             }
         }
 
@@ -602,7 +603,7 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
                         }
                     }
                 }
-                catch (GridException e) {
+                catch (IgniteCheckedException e) {
                     stopFuts.remove(routineId);
                     waitForStopAck.remove(routineId);
 
@@ -625,10 +626,10 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
      * @param obj Notification object.
      * @param orderedTopic Topic for ordered notifications.
      *      If {@code null}, non-ordered message will be sent.
      * @throws GridException In case of error.
      */
     public void addNotification(UUID nodeId, UUID routineId, @Nullable Object obj, @Nullable Object orderedTopic)
-        throws GridException {
+        throws IgniteCheckedException {
         assert nodeId != null;
         assert routineId != null;
 
@@ -650,10 +651,10 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
      * @param toSnd Notification object to send.
      * @param orderedTopic Topic for ordered notifications.
      *      If {@code null}, non-ordered message will be sent.
      * @throws GridException In case of error.
      */
     private void sendNotification(UUID nodeId, UUID routineId, Collection<Object> toSnd,
-        @Nullable Object orderedTopic) throws GridException {
+        @Nullable Object orderedTopic) throws IgniteCheckedException {
         assert nodeId != null;
         assert routineId != null;
         assert toSnd != null;
@@ -675,7 +676,7 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
 
         GridContinuousHandler hnd = data.hnd;
 
-        GridException err = null;
+        IgniteCheckedException err = null;
 
         try {
             if (ctx.config().isPeerClassLoadingEnabled()) {
@@ -696,7 +697,7 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
                 hnd.p2pUnmarshal(nodeId, ctx);
             }
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             err = e;
 
             U.error(log, "Failed to register handler [nodeId=" + nodeId + ", routineId=" + routineId + ']', e);
@@ -713,7 +714,7 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
                         data.autoUnsubscribe, false);
                 }
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 err = e;
 
                 U.error(log, "Failed to register handler [nodeId=" + nodeId + ", routineId=" + routineId + ']', e);
@@ -727,7 +728,7 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
             if (log.isDebugEnabled())
                 log.debug("Failed to send start acknowledgement to node (is node alive?): " + nodeId);
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             U.error(log, "Failed to send start acknowledgement to node: " + nodeId, e);
         }
 
@@ -745,7 +746,7 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
 
         UUID routineId = ack.routineId();
 
-        final GridException err = ack.data();
+        final IgniteCheckedException err = ack.data();
 
         if (err != null) {
             if (waitForStartAck.remove(routineId) != null) {
@@ -788,7 +789,7 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
             if (log.isDebugEnabled())
                 log.debug("Failed to send stop acknowledgement to node (is node alive?): " + nodeId);
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             U.error(log, "Failed to send stop acknowledgement to node: " + nodeId, e);
         }
     }
@@ -868,10 +869,10 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
      * @param autoUnsubscribe Automatic unsubscribe flag.
      * @param loc Local registration flag.
      * @return Whether listener was actually registered.
      * @throws GridException In case of error.
      */
     private boolean registerHandler(final UUID nodeId, final UUID routineId, final GridContinuousHandler hnd,
-        int bufSize, final long interval, boolean autoUnsubscribe, boolean loc) throws GridException {
+        int bufSize, final long interval, boolean autoUnsubscribe, boolean loc) throws IgniteCheckedException {
         assert nodeId != null;
         assert routineId != null;
         assert hnd != null;
@@ -920,7 +921,7 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
                                     if (log.isDebugEnabled())
                                         log.debug("Failed to send notification to node (is node alive?): " + nodeId);
                                 }
-                                catch (GridException e) {
+                                catch (IgniteCheckedException e) {
                                     U.error(log, "Failed to send notification to node: " + nodeId, e);
                                 }
                             }
@@ -984,10 +985,10 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
      * @param msg Message.
      * @param orderedTopic Topic for ordered notifications.
      *      If {@code null}, non-ordered message will be sent.
      * @throws GridException In case of error.
      */
     private void sendWithRetries(UUID nodeId, GridContinuousMessage msg, @Nullable Object orderedTopic)
-        throws GridException {
+        throws IgniteCheckedException {
         assert nodeId != null;
         assert msg != null;
 
@@ -1004,10 +1005,10 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
      * @param msg Message.
      * @param orderedTopic Topic for ordered notifications.
      *      If {@code null}, non-ordered message will be sent.
      * @throws GridException In case of error.
      */
     private void sendWithRetries(ClusterNode node, GridContinuousMessage msg, @Nullable Object orderedTopic)
-        throws GridException {
+        throws IgniteCheckedException {
         assert node != null;
         assert msg != null;
 
@@ -1019,10 +1020,10 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
      * @param msg Message.
      * @param orderedTopic Topic for ordered notifications.
      *      If {@code null}, non-ordered message will be sent.
      * @throws GridException In case of error.
      */
     private void sendWithRetries(Collection<? extends ClusterNode> nodes, GridContinuousMessage msg,
-        @Nullable Object orderedTopic) throws GridException {
+        @Nullable Object orderedTopic) throws IgniteCheckedException {
         assert !F.isEmpty(nodes);
         assert msg != null;
 
@@ -1060,7 +1061,7 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
                 catch (GridInterruptedException e) {
                     throw e;
                 }
-                catch (GridException e) {
+                catch (IgniteCheckedException e) {
                     if (!ctx.discovery().alive(node.id()))
                         throw new ClusterTopologyException("Node left grid while sending message to: " + node.id(), e);
 
@@ -1301,9 +1302,9 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
 
         /**
          * @param marsh Marshaller.
          * @throws GridException In case of error.
          */
-        void p2pMarshal(IgniteMarshaller marsh) throws GridException {
+        void p2pMarshal(IgniteMarshaller marsh) throws IgniteCheckedException {
             assert marsh != null;
 
             prjPredBytes = marsh.marshal(prjPred);
@@ -1312,9 +1313,9 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
         /**
          * @param marsh Marshaller.
          * @param ldr Class loader.
          * @throws GridException In case of error.
          */
-        void p2pUnmarshal(IgniteMarshaller marsh, @Nullable ClassLoader ldr) throws GridException {
+        void p2pUnmarshal(IgniteMarshaller marsh, @Nullable ClassLoader ldr) throws IgniteCheckedException {
             assert marsh != null;
 
             assert prjPred == null;
@@ -1687,7 +1688,7 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
                                 if (log.isDebugEnabled())
                                     log.debug("Failed to resend stop request to node (is node alive?): " + id);
                             }
-                            catch (GridException e) {
+                            catch (IgniteCheckedException e) {
                                 U.error(log, "Failed to resend stop request to node: " + id, e);
 
                                 ids.remove(id);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/dataload/GridDataLoadCacheUpdaters.java
----------------------------------------------------------------------
@@ -625,10 +626,10 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
      * @param orderedTopic Topic for ordered notifications.
      *      If {@code null}, non-ordered message will be sent.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     public void addNotification(UUID nodeId, UUID routineId, @Nullable Object obj, @Nullable Object orderedTopic)
@@ -650,10 +651,10 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
      * @param orderedTopic Topic for ordered notifications.
      *      If {@code null}, non-ordered message will be sent.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     private void sendNotification(UUID nodeId, UUID routineId, Collection<Object> toSnd,
@@ -868,10 +869,10 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
      * @param loc Local registration flag.
      * @return Whether listener was actually registered.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     private boolean registerHandler(final UUID nodeId, final UUID routineId, final GridContinuousHandler hnd,
@@ -984,10 +985,10 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
      * @param orderedTopic Topic for ordered notifications.
      *      If {@code null}, non-ordered message will be sent.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     private void sendWithRetries(UUID nodeId, GridContinuousMessage msg, @Nullable Object orderedTopic)
@@ -1004,10 +1005,10 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
      * @param orderedTopic Topic for ordered notifications.
      *      If {@code null}, non-ordered message will be sent.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     private void sendWithRetries(ClusterNode node, GridContinuousMessage msg, @Nullable Object orderedTopic)
@@ -1019,10 +1020,10 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
      * @param orderedTopic Topic for ordered notifications.
      *      If {@code null}, non-ordered message will be sent.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
     private void sendWithRetries(Collection<? extends ClusterNode> nodes, GridContinuousMessage msg,
@@ -1301,9 +1302,9 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
         /**
          * @param marsh Marshaller.
-         * @throws GridException In case of error.
+         * @throws IgniteCheckedException In case of error.
          */
@@ -1312,9 +1313,9 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
          * @param marsh Marshaller.
          * @param ldr Class loader.
-         * @throws GridException In case of error.
+         * @throws IgniteCheckedException In case of error.
          */
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/dataload/GridDataLoadCacheUpdaters.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/dataload/GridDataLoadCacheUpdaters.java
index 0fb1119..b097c8a 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/dataload/GridDataLoadCacheUpdaters.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/dataload/GridDataLoadCacheUpdaters.java
@@ -9,8 +9,8 @@
 
 package org.gridgain.grid.kernal.processors.dataload;
 
+import org.apache.ignite.*;
 import org.apache.ignite.dataload.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.cache.*;
 import org.gridgain.grid.util.typedef.*;
 import org.jetbrains.annotations.*;
@@ -87,10 +87,10 @@ public class GridDataLoadCacheUpdaters {
      * @param cache Cache.
      * @param rmvCol Keys to remove.
      * @param putMap Entries to put.
      * @throws GridException If failed.
      */
     protected static <K, V> void updateAll(GridCacheProjection<K,V> cache, @Nullable Collection<K> rmvCol,
-        Map<K, V> putMap) throws GridException {
+        Map<K, V> putMap) throws IgniteCheckedException {
         assert rmvCol != null || putMap != null;
 
         // Here we assume that there are no key duplicates, so the following calls are valid.
@@ -110,7 +110,7 @@ public class GridDataLoadCacheUpdaters {
 
         /** {@inheritDoc} */
         @Override public void update(GridCache<K, V> cache, Collection<Map.Entry<K, V>> entries)
-            throws GridException {
+            throws IgniteCheckedException {
             assert cache != null;
             assert !F.isEmpty(entries);
 
@@ -138,7 +138,7 @@ public class GridDataLoadCacheUpdaters {
 
         /** {@inheritDoc} */
         @Override public void update(GridCache<K, V> cache, Collection<Map.Entry<K, V>> entries)
-            throws GridException {
+            throws IgniteCheckedException {
             assert cache != null;
             assert !F.isEmpty(entries);
 
@@ -179,7 +179,7 @@ public class GridDataLoadCacheUpdaters {
 
         /** {@inheritDoc} */
         @Override public void update(GridCache<K, V> cache, Collection<Map.Entry<K, V>> entries)
-            throws GridException {
+            throws IgniteCheckedException {
             assert cache != null;
             assert !F.isEmpty(entries);
 
@@ -220,7 +220,7 @@ public class GridDataLoadCacheUpdaters {
 
         /** {@inheritDoc} */
         @Override public void update(GridCache<K, V> cache, Collection<Map.Entry<K, V>> entries)
-            throws GridException {
+            throws IgniteCheckedException {
             assert cache != null;
             assert !F.isEmpty(entries);
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/dataload/GridDataLoaderFuture.java
----------------------------------------------------------------------
@@ -87,10 +87,10 @@ public class GridDataLoadCacheUpdaters {
      * @param rmvCol Keys to remove.
      * @param putMap Entries to put.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     protected static <K, V> void updateAll(GridCacheProjection<K,V> cache, @Nullable Collection<K> rmvCol,